# qtregpy

This package provides the software tools to implement Quantile Transformation Regression introduced in
[Spady and Stouli (2020)](https://arxiv.org/pdf/2011.06416.pdf).

With the tools in this package it is possible to obtain inference and estimation results for conditional distribution,
quantile and density functions implied by flexible Gaussian representations.

For further details, please refer to the original text.

## Installation

You can install gtregpy with pip:

`pip install git+https://github.com/diego-lda/qtregpy.git`

## Usage

Here's a simple example of how to use gtregpy:

```python
from gtregpy import print_name

print_name("John")
```

## Documentation

You can find more detailed documentation for each function in the docs directory.

## Testing

To run the tests, use the following command:

```python
pytest tests/
```

## Contributing

We welcome contributions! Please see the [Contribution Guide](CONTRIBUTING.md) file for details on how to contribute.

## License

This package is licensed under the MIT license. See the LICENSE file for details.
